@@ -31,7 +31,9 @@ class CancellableStreamThread:
                     # agent unavailable or other rpc error
                     time.sleep(0.1)
 
-        threading.Thread(target=target, daemon=True).start()
+        t = threading.Thread(target=target)
+        t.daemon = True
+        t.start()
 
     def cancel(self):
         self.stream.cancel()
