@@ -41,7 +41,7 @@ def handle_agent_exceptions(func):
     def _(*args, **kwargs):
         error = None
         try:
-            func(*args, **kwargs)
+            return func(*args, **kwargs)
         except grpc.RpcError as e:
             error = e
 
